==> palmera_ethtx-1.0.3-py3-none-any.whl: ethtx/decoders/semantic/balances.py <==
# Copyright 2021 DAI FOUNDATION (the original version https://github.com/daifoundation/ethtx_ce)
# Copyright 2021-2022 Token Flow Insights SA (modifications to the original software as recorded
# in the changelog https://github.com/EthTx/ethtx/blob/master/CHANGELOG.md)
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at: http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software distributed under the License is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and limitations under the License.
#
# The product contains trademarks and other branding elements of Token Flow Insights SA which are
# not licensed under the Apache 2.0 license. When using or reproducing the code, please remove
# the trademark and/or other branding elements.

from typing import List

from ethtx.models.decoded_model import DecodedBalance, DecodedTransactionMetadata
from .abc import SemanticSubmoduleAbc
from .helpers.utils import get_badge


class SemanticBalancesDecoder(SemanticSubmoduleAbc):
    """Semantic Balances Decoder."""

    def decode(
        self, balances: List[DecodedBalance], tx_metadata: DecodedTransactionMetadata
    ) -> List[DecodedBalance]:
        """Semantically decode balances."""

        for balance in balances:
            # decode the proper holder badge
            balance.holder.badge = get_badge(
                balance.holder.address,
                tx_metadata.sender.address,
                tx_metadata.receiver.address,
            )

            for token in balance.tokens:
                token["balance"] = f"{token['balance']:,.4f}"

        return balances

==> palmera_ethtx-1.0.6-py3-none-any.whl: ethtx/decoders/semantic/balances.py <==
# Copyright 2021 DAI FOUNDATION (the original version https://github.com/daifoundation/ethtx_ce)
# Copyright 2021-2022 Token Flow Insights SA (modifications to the original software as recorded
# in the changelog https://github.com/EthTx/ethtx/blob/master/CHANGELOG.md)
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at: http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software distributed under the License is distributed
# on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and limitations under the License.
#
# The product contains trademarks and other branding elements of Token Flow Insights SA which are
# not licensed under the Apache 2.0 license. When using or reproducing the code, please remove
# the trademark and/or other branding elements.

from typing import List

from palmera_ethtx.models.decoded_model import DecodedBalance, DecodedTransactionMetadata
from .abc import SemanticSubmoduleAbc
from .helpers.utils import get_badge


class SemanticBalancesDecoder(SemanticSubmoduleAbc):
    """Semantic Balances Decoder."""

    def decode(
        self, balances: List[DecodedBalance], tx_metadata: DecodedTransactionMetadata
    ) -> List[DecodedBalance]:
        """Semantically decode balances."""

        for balance in balances:
            # decode the proper holder badge
            balance.holder.badge = get_badge(
                balance.holder.address,
                tx_metadata.sender.address,
                tx_metadata.receiver.address,
            )

            for token in balance.tokens:
                token.balance = f"{float(token.balance):,.4f}"

        return balances
